nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Bytcnt

Struct Bytcnt 

#[repr(transparent)]
pub struct Bytcnt(pub u32);
Byte Count register

Tuple Fields

0: u32

Implementations

Source

impl Bytcnt

pub const fn byte_count(&self) -> u32

Number of bytes to be transferred; should be integer multiple of Block Size for block transfers.

pub const fn set_byte_count(&mut self, val: u32)

Number of bytes to be transferred; should be integer multiple of Block Size for block transfers.