nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Cmd

Struct Cmd 

#[repr(transparent)]
pub struct Cmd(pub u32);
Command register

Tuple Fields

0: u32

Implementations

Source

impl Cmd

pub const fn cmd_index(&self) -> u8

Command index.

pub const fn set_cmd_index(&mut self, val: u8)

Command index.

pub const fn response_expect(&self) -> bool

Response expect.

pub const fn set_response_expect(&mut self, val: bool)

Response expect.

pub const fn response_length(&self) -> bool

Response length.

pub const fn set_response_length(&mut self, val: bool)

Response length.

pub const fn check_response_crc(&self) -> bool

Check response CRC.

pub const fn set_check_response_crc(&mut self, val: bool)

Check response CRC.

pub const fn data_expected(&self) -> bool

Data expected.

pub const fn set_data_expected(&mut self, val: bool)

Data expected.

pub const fn read_write(&self) -> bool

read/write.

pub const fn set_read_write(&mut self, val: bool)

read/write.

pub const fn transfer_mode(&self) -> bool

Transfer mode.

pub const fn set_transfer_mode(&mut self, val: bool)

Transfer mode.

pub const fn send_auto_stop(&self) -> bool

Send auto stop.

pub const fn set_send_auto_stop(&mut self, val: bool)

Send auto stop.

pub const fn wait_prvdata_complete(&self) -> bool

Wait prvdata complete.

pub const fn set_wait_prvdata_complete(&mut self, val: bool)

Wait prvdata complete.

pub const fn stop_abort_cmd(&self) -> bool

Stop abort command.

pub const fn set_stop_abort_cmd(&mut self, val: bool)

Stop abort command.

pub const fn send_initialization(&self) -> bool

Send initialization.

pub const fn set_send_initialization(&mut self, val: bool)

Send initialization.

pub const fn card_number(&self) -> CardNumber

Specifies the card number of SDCARD for which the current Command is being executed

pub const fn set_card_number(&mut self, val: CardNumber)

Specifies the card number of SDCARD for which the current Command is being executed

pub const fn update_clock_registers_only(&self) -> bool

Update clock registers only.

pub const fn set_update_clock_registers_only(&mut self, val: bool)

Update clock registers only.

pub const fn read_ceata_device(&self) -> bool

Read ceata device.

pub const fn set_read_ceata_device(&mut self, val: bool)

Read ceata device.

pub const fn ccs_expected(&self) -> bool

CCS expected.

pub const fn set_ccs_expected(&mut self, val: bool)

CCS expected.

pub const fn enable_boot(&self) -> bool

Enable Boot - this bit should be set only for mandatory boot mode.

pub const fn set_enable_boot(&mut self, val: bool)

Enable Boot - this bit should be set only for mandatory boot mode.

pub const fn expect_boot_ack(&self) -> bool

Expect Boot Acknowledge.

pub const fn set_expect_boot_ack(&mut self, val: bool)

Expect Boot Acknowledge.

pub const fn disable_boot(&self) -> bool

Disable Boot.

pub const fn set_disable_boot(&mut self, val: bool)

Disable Boot.

pub const fn boot_mode(&self) -> bool

Boot Mode.

pub const fn set_boot_mode(&mut self, val: bool)

Boot Mode.

pub const fn volt_switch(&self) -> bool

Voltage switch bit.

pub const fn set_volt_switch(&mut self, val: bool)

Voltage switch bit.

pub const fn use_hold_reg(&self) -> bool

Use Hold Register.

pub const fn set_use_hold_reg(&mut self, val: bool)

Use Hold Register.

pub const fn start_cmd(&self) -> bool

Start command.

pub const fn set_start_cmd(&mut self, val: bool)

Start command.