nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Pwren

Struct Pwren 

#[repr(transparent)]
pub struct Pwren(pub u32);
Power Enable register

Tuple Fields

0: u32

Implementations

Source

impl Pwren

pub const fn power_enable0(&self) -> bool

Power on/off switch for card 0; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 0.

pub const fn set_power_enable0(&mut self, val: bool)

Power on/off switch for card 0; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 0.

pub const fn power_enable1(&self) -> bool

Power on/off switch for card 1; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 1.

pub const fn set_power_enable1(&mut self, val: bool)

Power on/off switch for card 1; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 1.