#[repr(transparent)]pub struct Tmout(pub u32);Expand description
Time-out register
Tuple Fields
0: u32Implementations
Sourceimpl Tmout
impl Tmout
Sourcepub const fn response_timeout(&self) -> u8
pub const fn response_timeout(&self) -> u8
Response time-out value.
Sourcepub const fn set_response_timeout(&mut self, val: u8)
pub const fn set_response_timeout(&mut self, val: u8)
Response time-out value.
Sourcepub const fn data_timeout(&self) -> u32
pub const fn data_timeout(&self) -> u32
Value for card Data Read time-out; same value also used for Data Starvation by Host time-out.
Sourcepub const fn set_data_timeout(&mut self, val: u32)
pub const fn set_data_timeout(&mut self, val: u32)
Value for card Data Read time-out; same value also used for Data Starvation by Host time-out.