#[repr(transparent)]pub struct Bytcnt(pub u32);Expand description
Byte Count register
Tuple Fields
0: u32Implementations
Sourceimpl Bytcnt
impl Bytcnt
Sourcepub const fn byte_count(&self) -> u32
pub const fn byte_count(&self) -> u32
Number of bytes to be transferred; should be integer multiple of Block Size for block transfers.
Sourcepub const fn set_byte_count(&mut self, val: u32)
pub const fn set_byte_count(&mut self, val: u32)
Number of bytes to be transferred; should be integer multiple of Block Size for block transfers.