#[repr(transparent)]pub struct Pwren(pub u32);Expand description
Power Enable register
Tuple Fields
0: u32Implementations
Sourceimpl Pwren
impl Pwren
Sourcepub const fn power_enable0(&self) -> bool
pub const fn power_enable0(&self) -> bool
Power on/off switch for card 0; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 0.
Sourcepub const fn set_power_enable0(&mut self, val: bool)
pub const fn set_power_enable0(&mut self, val: bool)
Power on/off switch for card 0; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 0.
Sourcepub const fn power_enable1(&self) -> bool
pub const fn power_enable1(&self) -> bool
Power on/off switch for card 1; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 1.
Sourcepub const fn set_power_enable1(&mut self, val: bool)
pub const fn set_power_enable1(&mut self, val: bool)
Power on/off switch for card 1; once power is turned on, software should wait for regulator/switch ramp-up time before trying to initialize card 1.